enqueueSync method
Appends a queue entry. Should only be invoked inside transaction alongside the corresponding domain-table mutation.
Implementation
@override
Future<void> enqueueSync(SyncQueueEntry entry) async {
_queue.add(entry);
}
Appends a queue entry. Should only be invoked inside transaction alongside the corresponding domain-table mutation.
@override
Future<void> enqueueSync(SyncQueueEntry entry) async {
_queue.add(entry);
}