setMeta method
Inserts or replaces the value for key in _sync_meta. Atomic
with respect to transaction; rolled back on throw. Added in 0.2.0.
Implementation
@override
Future<void> setMeta(String key, String value) async {
_meta[key] = value;
}
Inserts or replaces the value for key in _sync_meta. Atomic
with respect to transaction; rolled back on throw. Added in 0.2.0.
@override
Future<void> setMeta(String key, String value) async {
_meta[key] = value;
}