adapter property
RemoteSyncAdapter
get
adapter
The adapter under test, already wired to the backend.
Implementation
RemoteSyncAdapter get adapter;
The adapter under test, already wired to the backend.
RemoteSyncAdapter get adapter;